@@ -127,7 +127,14 @@
                            centroids[group, !pos, drop=FALSE])
 
     ## zij are the distances of each point to its group centroid
-    zij <- sqrt(abs(dist.pos - dist.neg))
+    if (any(dist.neg > dist.pos)) {
+        ## Negative squared distances give complex valued distances:
+        ## take only the real part (which is zero). Github issue #306.
+        warning("some squared distances are negative and changed to zero")
+        zij <- Re(sqrt(as.complex(dist.pos - dist.neg)))
+    } else {
+        zij <- sqrt(dist.pos - dist.neg)
+    }
     if (bias.adjust) {
         n.group <- as.vector(table(group))
         zij <- zij*sqrt(n.group[group]/(n.group[group]-1))
